@@ -21,7 +21,11 @@ use {
         },
         *,
     },
-    crokey::{OneToThree, KeyCombination, key},
+    crokey::{
+        key,
+        KeyCombination,
+        OneToThree,
+    },
     std::io::Write,
 };
 
@@ -69,7 +73,7 @@ macro_rules! wrap_content_fun {
 
 impl InputField {
     pub const ENTER: KeyCombination = key!(enter);
-    pub const ALT_ENTER: KeyCombination = key!(alt-enter);
+    pub const ALT_ENTER: KeyCombination = key!(alt - enter);
 
     pub fn new(area: Area) -> Self {
         let focused_style = CompoundStyle::default();
@@ -282,10 +286,7 @@ impl InputField {
     /// of the input. If you want to totally handle events, you
     /// may call function like `put_char` and `del_char_left`
     /// directly.
-    pub fn apply_key_combination<K: Into<KeyCombination>>(
-        &mut self,
-        key: K,
-    ) -> bool {
+    pub fn apply_key_combination<K: Into<KeyCombination>>(&mut self, key: K) -> bool {
         if !self.focused {
             return false;
         }
@@ -431,7 +432,9 @@ impl InputField {
     pub fn apply_event(&mut self, event: &Event, is_double_click: bool) -> bool {
         match event {
             Event::Mouse(mouse_event) => self.apply_mouse_event(*mouse_event, is_double_click),
-            Event::Key(KeyEvent { code, modifiers, .. }) if self.focused => {
+            Event::Key(KeyEvent {
+                code, modifiers, ..
+            }) if self.focused => {
                 if modifiers.is_empty() {
                     self.apply_keycode_event(*code, false)
                 } else if *modifiers == KeyModifiers::SHIFT {
@@ -543,9 +546,13 @@ impl InputField {
     /// All rendering must be explicitely called, no rendering is
     /// done on functions changing the state.
     ///
+    /// This function also returns the cursor position in the form
+    /// `Ok(Some((left, top)))` if the terminal cursor is rendered.
+    /// Otherwise, this function returns `Ok(None)`.
+    ///
     /// w is typically either stderr or stdout. This function doesn't
     /// flush by itself (useful to avoid flickering)
-    pub fn display_on<W: Write>(&self, w: &mut W) -> Result<(), Error> {
+    pub fn display_on<W: Write>(&self, w: &mut W) -> Result<Option<(u16, u16)>, Error> {
         let normal_style = if self.focused {
             &self.focused_style
         } else {
@@ -554,6 +561,7 @@ impl InputField {
 
         let mut width = self.area.width as usize;
         let pos = self.content.cursor_pos();
+        let mut terminal_cursor_pos = None;
         let scrollbar = self
             .area
             .scrollbar(self.scroll.y as u16, self.content.line_count() as u16);
@@ -609,6 +617,11 @@ impl InputField {
                         if !is_last || displayed_width + char_width > width {
                             if self.focused && selection.contains(i, y) {
                                 self.cursor_style.queue(w, fit::ELLIPSIS)?;
+                                // set terminal cursor position
+                                terminal_cursor_pos = Some((
+                                    self.area.left + displayed_width as u16,
+                                    self.area.top + j,
+                                ));
                             } else {
                                 normal_style.queue(w, fit::ELLIPSIS)?;
                             }
@@ -618,6 +631,9 @@ impl InputField {
                     }
                     if self.focused && selection.contains(i, y) {
                         self.cursor_style.queue(w, c)?;
+                        // set terminal cursor position
+                        terminal_cursor_pos =
+                            Some((self.area.left + displayed_width as u16, self.area.top + j));
                     } else {
                         normal_style.queue(w, c)?;
                     }
@@ -628,6 +644,9 @@ impl InputField {
                 }
                 if displayed_width < width && cursor_at_end {
                     self.cursor_style.queue(w, ' ')?;
+                    // set terminal cursor position
+                    terminal_cursor_pos =
+                        Some((self.area.left + displayed_width as u16, self.area.top + j));
                     displayed_width += 1;
                 }
                 while displayed_width < width {
@@ -646,14 +665,16 @@ impl InputField {
                 }
             }
         }
-        Ok(())
+        Ok(terminal_cursor_pos)
     }
 
     /// render the input field on stdout
-    pub fn display(&self) -> Result<(), Error> {
+    ///
+    /// Return the input field position if the cursor is displayed
+    pub fn display(&self) -> Result<Option<(u16, u16)>, Error> {
         let mut w = std::io::stdout();
-        self.display_on(&mut w)?;
+        let pos = self.display_on(&mut w)?;
         w.flush()?;
-        Ok(())
+        Ok(pos)
     }
 }
